@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw(Alien::Base);
 
-our $VERSION = '0.000_002';
+our $VERSION = '0.001_001';
 $VERSION = eval $VERSION;
 
 1;
@@ -34,7 +34,7 @@ Alien::Chipmunk - Alien package for the Chipmunk Physics library
             # ...
         },
         extra_compiler_flags => $alien->cflags,
-        extra_linker_flags   => $alien->libs . ' -lm',
+        extra_linker_flags   => $alien->libs,
     );
 
     $builder->create_build_script();
